/*
 * Copyright 2013 Andrea "andynaz" Agnesse
 * 
 * This file is part of "iRex DR1000 Merger".
 * 
 * "iRex DR1000 Merger" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 * 
 * "iRex DR1000 Merger" is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * "iRex DR1000 Merger".  If not, see <http://www.gnu.org/licenses/>.
 * 
 * author e-mail: andynaz@gmail.com
 * author home page: http://andynaz.altervista.org
 * program official page: http://andynaz.altervista.org/Progetti/iRexDR1000Merger.shtm
 */

package it.andynaz.irex.dr1000.scribble;

import java.awt.Color;
import java.util.*;
import com.lowagie.text.pdf.PdfContentByte;
import it.andynaz.irex.dr1000.util.ColorMgr;

/**
 * Represent a page of scribbles.
 * 
 * A page is made of various {@link Stroke strokes}.
 * 
 * <p>To create a {@code Page} object from a blob, use the {@link
 * Parser#build(byte[])} method.</p>
 *
 * @author andynaz
 * @version 2013/09/22
 */
public class Page {
	
	/**
	 * List of strokes.
	 * 
	 * Contains all the strokes in the page.
	 */
	private List<Stroke> strokes = new ArrayList<Stroke>();
	

	/**
	 * Creates a new Page object.
	 */
	public Page(){ }

	/**
	 * Add a stroke.
	 * 
	 * The stroke is added only if it is not {@code null}.
	 * 
	 * @param s the stroke to be added
	 */
	public void addStroke(Stroke s){
		if (s!=null)
			strokes.add(s);
	}
	
	/**
	 * Returns the list of strokes in this page.
	 * 
	 * @return the list of strokes in this page
	 */
	public List<Stroke> getStrokes(){
		return strokes;
	}

	/**
	 * Draw all the strokes of this page.
	 * 
	 * @param cb the content of the PDF
	 * @param xAdjust the parameter to adjust the 'x' coordinates of the strokes
	 * @param yAdjust the parameter to adjust the 'y' coordinates of the strokes
	 * @param c color of the strokes
	 */
	public void drawStrokes(PdfContentByte cb, float xAdjust, float yAdjust, Color c) {
		for (Stroke stroke : strokes){
			stroke.draw(cb, xAdjust, yAdjust, c);
		}
	}

	/**
	 * Draw all the strokes of this page, using the color in the {@link ColorMgr}
	 * class.
	 * 
	 * @param cb the content of the PDF
	 * @param xAdjust the parameter to adjust the 'x' coordinates of the strokes
	 * @param yAdjust the parameter to adjust the 'y' coordinates of the strokes
	 * 
	 * @see #drawStrokes(PdfContentByte, float, float, Color)
	 */
	public void drawStrokes(PdfContentByte cb, float xAdjust, float yAdjust) {
		drawStrokes(cb, xAdjust, yAdjust, ColorMgr.getColor());
	}

}
