/*
 * Copyright 2013 Andrea "andynaz" Agnesse
 * 
 * This file is part of "iRex DR1000 Merger".
 * 
 * "iRex DR1000 Merger" is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 * 
 * "iRex DR1000 Merger" is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * "iRex DR1000 Merger".  If not, see <http://www.gnu.org/licenses/>.
 * 
 * author e-mail: andynaz@gmail.com
 * author home page: http://andynaz.altervista.org
 * program official page: http://andynaz.altervista.org/Progetti/iRexDR1000Merger.shtm
 */

package it.andynaz.irex.dr1000.util;

import it.andynaz.config.ConfigMgr;
import it.andynaz.utils.Utils;
import java.awt.Color;

/**
 * Manage the color used for the stroke.
 * 
 * The color can be retrived with the {@link #getColor()} method.
 * 
 * <p>This class contains a default color to be used in the strokes and an
 * {@link #setColor(String) method} to safely initialize the color. When the
 * class is first loaded, the default color is set using the parameter "color"
 * from the {@code ConfigMgr} class from <i>andyLib</i>. In this way a color is
 * always available.</p>
 * 
 * <p>In all the methods, color codes can be specified both as a {@code RRGGBB}
 * or a {@code #RRGGBB} string.</p>
 *
 * @author andynaz
 * @version 2013/09/22
 */
public class ColorMgr {
	
	/**
	 * Default color to use in strokes.
	 */
	private static Color color = Color.BLACK;
	
	static{
		setColor(ConfigMgr.getConfigParam("color"));
	}

	//hides the constructor
	private ColorMgr(){}
	
	/**
	 * Safely set the color.
	 * 
	 * If the {@code colorCode} does not correspond to a valid color code, this
	 * method does nothing.
	 * 
	 * @param colorCode numeric code of the color
	 */
	public static void setColor(String colorCode){
		if (!Utils.isEmpty(colorCode))
			try{
				color = Color.decode(normalizeColorCode(colorCode));
			} catch(Exception e){ }
	}

	/**
	 * Returns the color in the class.
	 * 
	 * @return the color
	 */
	public static Color getColor() {
		return color;
	}
	
	/**
	 * Normalize the color code.
	 * 
	 * A '#' character is added at the beginning of the string {@code s} if it do
	 * not begin with '#'.
	 * 
	 * @param s a string color code
	 * @return the same string suitable to be used with the method {@link
	 * Color#decode(String)}
	 */
	private static String normalizeColorCode(String s) {
		return s.startsWith("#") ? s : '#'+s;
	}
	
}
